@@ -54,8 +54,10 @@ pub fn encrypt_file(
                 rpassword::prompt_password("Password: ").context("Unable to read password")?;
             let input_validation = rpassword::prompt_password("Password (for validation): ")
                 .context("Unable to read password")?;
-            if input == input_validation {
+            if input == input_validation && !input.is_empty() {
                 break input.as_bytes().to_vec();
+            } else if input.is_empty() {
+                println!("Password cannot be empty, please try again.");
             } else {
                 println!("The passwords aren't the same, please try again.");
             }
