@@ -1,8 +1,8 @@
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 
 #[derive(Serialize, Deserialize)]
 pub struct DexiosFile {
     pub salt: String,
     pub nonce: String,
     pub data: String,
-}
\ No newline at end of file
+}
